
from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class VideosConfig(AppConfig):
    name = 'gallery.videos'
    verbose_name = _("Videos")


default_app_config = 'gallery.videos.VideosConfig'




from modeltranslation.translator import translator, TranslationOptions

from gallery.videos.models import Album, Video


class AlbumTranslationOptions(TranslationOptions):
    fields = ('name', 'short_description', 'full_description', )


class VideoTranslationOptions(TranslationOptions):
    fields = ('name', 'description', )


translator.register(Album, AlbumTranslationOptions)
translator.register(Video, VideoTranslationOptions)



# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2017-11-03 12:48
from __future__ import unicode_literals

import ckeditor_uploader.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('videos', '0002_auto_20170329_0817'),
    ]

    operations = [
        migrations.AddField(
            model_name='album',
            name='site',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name='video_albums', to='sites.Site', verbose_name='Site'),
        ),
        migrations.AlterField(
            model_name='album',
            name='name',
            field=models.CharField(max_length=255, verbose_name='\u0406\u043c\u02bc\u044f'),
        ),
        migrations.AlterField(
            model_name='video',
            name='name',
            field=models.CharField(max_length=255, verbose_name='\u0406\u043c\u02bc\u044f'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2017-03-07 17:45
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import gallery.videos.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Album',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('order', models.PositiveIntegerField(db_index=True, editable=False)),
                ('name', models.CharField(max_length=255, verbose_name='\u041d\u0430\u0437\u0432\u0430')),
                ('logo', models.ImageField(blank=True, upload_to=gallery.videos.models.get_album_upload_path, verbose_name='\u041b\u043e\u0433\u043e\u0442\u0438\u043f')),
                ('description', models.CharField(blank=True, max_length=255, verbose_name='\u041e\u043f\u0438\u0441')),
            ],
            options={
                'ordering': ('order',),
                'abstract': False,
                'verbose_name': '\u0410\u043b\u044c\u0431\u043e\u043c',
                'verbose_name_plural': '\u0410\u043b\u044c\u0431\u043e\u043c\u0438',
            },
        ),
        migrations.CreateModel(
            name='Video',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('order', models.PositiveIntegerField(db_index=True, editable=False)),
                ('name', models.CharField(max_length=255, verbose_name='\u041d\u0430\u0437\u0432\u0430')),
                ('logo', models.ImageField(blank=True, upload_to=gallery.videos.models.get_video_logo_upload_path, verbose_name='\u041b\u043e\u0433\u043e\u0442\u0438\u043f')),
                ('code', models.CharField(max_length=255, verbose_name='\u041a\u043e\u0434')),
                ('description', models.CharField(blank=True, max_length=255, verbose_name='\u041e\u043f\u0438\u0441')),
                ('album', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='videos', to='videos.Album', verbose_name='\u0410\u043b\u044c\u0431\u043e\u043c')),
            ],
            options={
                'ordering': ('order',),
                'abstract': False,
                'verbose_name': '\u0412\u0456\u0434\u0435\u043e',
                'verbose_name_plural': '\u0412\u0456\u0434\u0435\u043e',
            },
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2017-03-29 08:17
from __future__ import unicode_literals

import ckeditor_uploader.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('videos', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='album',
            old_name='description',
            new_name='short_description',
        ),
        migrations.AddField(
            model_name='album',
            name='full_description',
            field=ckeditor_uploader.fields.RichTextUploadingField(blank=True, max_length=10000, verbose_name='Full description'),
        ),
        migrations.AlterField(
            model_name='album',
            name='name',
            field=models.CharField(max_length=255, verbose_name="\u0406\u043c'\u044f"),
        ),
        migrations.AlterField(
            model_name='video',
            name='name',
            field=models.CharField(max_length=255, verbose_name="\u0406\u043c'\u044f"),
        ),
    ]




from modeltranslation.translator import translator, TranslationOptions

from gallery.photos.models import Album


class AlbumTranslationOptions(TranslationOptions):
    fields = ('name', 'short_description', 'full_description', )


translator.register(Album, AlbumTranslationOptions)




from django.db import models
from django.core.urlresolvers import reverse
from django.conf import settings
from django.utils.translation import ugettext as _
from django.contrib.sites.models import Site

from slugify import slugify_url
from ordered_model.models import OrderedModel
from ckeditor_uploader.fields import RichTextUploadingField


def get_album_upload_path(instance, filename):
    ext = filename.split('.')[-1]
    return '%s/%s.%s' % ('video_album_logos', instance.slug, ext)


def get_video_logo_upload_path(instance, filename):
    return '%s/%s/%s' % ('video_logos', instance.album.slug, filename)


class Album(OrderedModel):

    site = models.ForeignKey(
        Site, verbose_name=_('Site'),related_name='video_albums',
        default=settings.SITE_ID)

    name = models.CharField(_('Name'), max_length=255, blank=False)

    logo = models.ImageField(
        _('Logo'), blank=True, upload_to=get_album_upload_path)

    short_description = models.CharField(
        _('Description'), max_length=255, blank=True)

    full_description = RichTextUploadingField(
        _('Full description'), max_length=10000, blank=True)

    objects = models.Manager()

    @property
    def slug(self):
        return slugify_url(self.name, separator='_')

    def get_absolute_url(self):
        return reverse('videos:video-list', kwargs={
            'album_slug': self.slug,
            'album_pk': self.pk
        })

    def __unicode__(self):
        return self.name

    class Meta(OrderedModel.Meta):
        verbose_name = _('Album')
        verbose_name_plural = _('Albums')


class Video(OrderedModel):

    album = models.ForeignKey(
        Album, verbose_name=_('Album'), related_name='videos')

    name = models.CharField(_('Name'), max_length=255, blank=False)

    logo = models.ImageField(
        _('Logo'), blank=True, upload_to=get_video_logo_upload_path)

    code = models.CharField(_('Code'), max_length=255)

    description = models.CharField(
        _('Description'), max_length=255, blank=True)

    order_with_respect_to = 'album'

    @property
    def slug(self):
        return slugify_url(self.name, separator='_')

    def get_absolute_url(self):
        return reverse('videos:video-info', kwargs={
            'album_slug': self.album.slug,
            'album_pk': self.album.pk,
            'video_slug': self.slug,
            'video_pk': self.pk,
        })

    def __unicode__(self):
        return self.name

    class Meta(OrderedModel.Meta):
        verbose_name = _('Video')
        verbose_name_plural = _('Videos')




from django.conf.urls import url

from gallery.photos import views


urlpatterns = [

    url(r'^$', views.album_list, name='album-list'),

    url(r'^(?P<album_slug>\w+)_(?P<album_pk>\d+)/$', views.photo_list,
        name='photo-list'),

]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2017-03-29 08:16
from __future__ import unicode_literals

import ckeditor_uploader.fields
from django.db import migrations, models
import django.db.models.deletion
import gallery.photos.models


class Migration(migrations.Migration):

    dependencies = [
        ('photos', '0002_auto_20170224_0918'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='album',
            options={'ordering': ('order',), 'verbose_name': '\u0410\u043b\u044c\u0431\u043e\u043c', 'verbose_name_plural': '\u0410\u043b\u044c\u0431\u043e\u043c\u0438'},
        ),
        migrations.AlterModelOptions(
            name='photo',
            options={'ordering': ('order',), 'verbose_name': '\u0424\u043e\u0442\u043e', 'verbose_name_plural': '\u0424\u043e\u0442\u043e'},
        ),
        migrations.RenameField(
            model_name='album',
            old_name='description',
            new_name='short_description',
        ),
        migrations.AddField(
            model_name='album',
            name='full_description',
            field=ckeditor_uploader.fields.RichTextUploadingField(blank=True, max_length=10000, verbose_name='Full description'),
        ),
        migrations.AlterField(
            model_name='album',
            name='logo',
            field=models.ImageField(blank=True, upload_to=gallery.photos.models.get_album_upload_path, verbose_name='\u041b\u043e\u0433\u043e\u0442\u0438\u043f'),
        ),
        migrations.AlterField(
            model_name='album',
            name='name',
            field=models.CharField(max_length=255, verbose_name="\u0406\u043c'\u044f"),
        ),
        migrations.AlterField(
            model_name='photo',
            name='album',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='photos', to='photos.Album', verbose_name='\u0410\u043b\u044c\u0431\u043e\u043c'),
        ),
    ]




from django.shortcuts import render, get_object_or_404

from pure_pagination import Paginator
from misc.utils import get_site_id_from_request

from gallery.photos.models import Album


def album_list(request):

    albums = Album.objects.filter(site_id=get_site_id_from_request(request))

    return render(request, 'gallery/album_list.html', {'albums': albums})


def photo_list(request, album_slug, album_pk):

    album = get_object_or_404(
        Album, pk=album_pk, site_id=get_site_id_from_request(request))

    paginator = Paginator(album.photos.all(), 20, request=request)

    context = {
        'album': album,
        'photos': paginator.page(request.GET.get('page', 1))
    }

    return render(request, 'gallery/photo_list.html', context)




import gallery.videos.translation

from django.contrib import admin

from ordered_model.admin import OrderedModelAdmin
from sorl.thumbnail import get_thumbnail
from modeltranslation.admin import TranslationAdmin

from gallery.videos.models import Video, Album


class AlbumsAdmin(OrderedModelAdmin, TranslationAdmin):

    list_display = ['name', 'site', 'move_up_down_links']

    list_filter =  ['site']


class VideoAdmin(OrderedModelAdmin, TranslationAdmin):

    list_display = ['name', 'preview', 'album', 'move_up_down_links']

    list_filter = ['album']

    def preview(self, item):
        try:
            preview = get_thumbnail(item.logo, '100x100', crop='center', quality=99)
            return '<img src="%s" style="width: 60px;" />' % preview.url
        except Exception as e:
            return '--------'

    preview.allow_tags = True


admin.site.register(Album, AlbumsAdmin)
admin.site.register(Video, VideoAdmin)




from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class PhotosConfig(AppConfig):
    name = 'gallery.photos'
    verbose_name = _("Photos")


default_app_config = 'gallery.photos.PhotosConfig'




from django.conf.urls import url

from gallery.videos import views


urlpatterns = [

    url(r'^$', views.album_list, name='album-list'),

    url(r'^(?P<album_slug>\w+)_(?P<album_pk>\d+)/$', views.video_list,
        name='video-list'),

    url(r'^(?P<album_slug>\w+)_(?P<album_pk>\d+)/'
        r'(?P<video_slug>\w+)_(?P<video_pk>\d+)/$', views.video_info,
        name='video-info'),

]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2017-02-24 09:18
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('photos', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='album',
            name='description',
            field=models.CharField(blank=True, max_length=255, verbose_name='\u041e\u043f\u0438\u0441'),
        ),
    ]




from django.shortcuts import render, get_object_or_404

from pure_pagination import Paginator
from misc.utils import get_site_id_from_request

from gallery.videos.models import Album


def album_list(request):

    albums = Album.objects.filter(site_id=get_site_id_from_request(request))

    return render(request, 'gallery/album_list.html', {'albums': albums})


def video_list(request, album_slug, album_pk):

    album = get_object_or_404(
        Album, pk=album_pk, site_id=get_site_id_from_request(request))

    paginator = Paginator(album.videos.all(), 20, request=request)

    context = {
        'album': album,
        'videos': paginator.page(request.GET.get('page', 1))
    }

    return render(request, 'gallery/video_list.html', context)


def video_info(request, album_slug, album_pk, video_slug, video_pk):

    album = get_object_or_404(
        Album, pk=album_pk, site_id=get_site_id_from_request(request))

    video = get_object_or_404(album.videos.all(), pk=video_pk)

    context = {
        'album': album,
        'video': video
    }

    return render(request, 'gallery/video_info.html', context)




import gallery.photos.translation

from django.contrib import admin
from django import forms
from django.utils.translation import ugettext as _

from multiupload.fields import MultiFileField
from ordered_model.admin import OrderedModelAdmin
from sorl.thumbnail import get_thumbnail
from modeltranslation.admin import TranslationAdmin

from gallery.photos.models import Photo, Album


class AlbumsAdmin(OrderedModelAdmin, TranslationAdmin):

    list_display = ['name', 'site', 'move_up_down_links']

    list_filter = ['site']


class UploadPhotosAdminForm(forms.ModelForm):

    album = forms.ModelChoiceField(
        label=_("Album"), required=True, queryset=Album.objects.all())

    images = MultiFileField(label=_('Images'), max_num=100, min_num=1)

    class Meta:
        model = Photo
        exclude = ['order', 'file']


class PhotosAdmin(OrderedModelAdmin):

    list_display = ['file', 'preview', 'album', 'move_up_down_links']

    list_filter = ['album']

    def preview(self, item):
        try:
            preview = get_thumbnail(item.logo, '100x100', crop='center', quality=99)
            return '<img src="%s" style="width: 60px;" />' % preview.url
        except Exception as e:
            return '--------'
    preview.allow_tags = True

    def save_model(self, request, obj, form, change):

        files = request.FILES.getlist('images')
        data = form.cleaned_data
        for file in files:
            self.model.objects.create(
                album=data['album'],
                file=file
            ).top()

    def get_form(self, request, obj=None, **kwargs):
        if obj is None:
            return UploadPhotosAdminForm
        else:
            return super(PhotosAdmin, self).get_form(request, obj, **kwargs)


admin.site.register(Album, AlbumsAdmin)
admin.site.register(Photo, PhotosAdmin)



# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2017-02-19 15:58
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import gallery.photos.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Album',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('order', models.PositiveIntegerField(db_index=True, editable=False)),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('logo', models.ImageField(blank=True, upload_to=gallery.photos.models.get_album_upload_path, verbose_name='Logo')),
                ('description', models.CharField(max_length=255, verbose_name='\u041e\u043f\u0438\u0441')),
            ],
            options={
                'ordering': ('order',),
                'abstract': False,
                'verbose_name': 'Album',
                'verbose_name_plural': 'Albums',
            },
        ),
        migrations.CreateModel(
            name='Photo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('order', models.PositiveIntegerField(db_index=True, editable=False)),
                ('file', models.ImageField(upload_to=gallery.photos.models.get_photo_upload_path, verbose_name='\u0424\u0430\u0439\u043b')),
                ('album', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='photos.Album', verbose_name='Album')),
            ],
            options={
                'ordering': ('order',),
                'abstract': False,
                'verbose_name': 'Photo',
                'verbose_name_plural': 'Photos',
            },
        ),
    ]
